@@ -74,13 +74,14 @@ use crate::{
     util::newmap,
     value::{get_bytes, Value},
 };
+use parking_lot::{Mutex, RwLock};
 use std::{
     cell::{Cell, RefCell},
     cmp::Ordering,
     collections::{BTreeMap, BTreeSet, HashMap, HashSet},
     panic,
     rc::Rc,
-    sync::{Arc, Mutex, RwLock},
+    sync::Arc,
 };
 
 /// Utility functions and macros.
